from setuptools import setup, find_packages

setup(
    name="talklabs",
    version="1.0.1",
    author="Francisco Lima",
    author_email="franciscorllima@gmail.com",
    description="TalkLabs SDK - ElevenLabs compatible Text-to-Speech API client",
    long_description=open("README.md", "r", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    url="https://talklabs.com.br",
    packages=find_packages(),
    install_requires=[
        "requests>=2.28.0",
        "websockets>=10.0",
        "pydantic>=2.0",
        "fastapi>=0.100.0",
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.8",
)
