"""
TalkLabs SDK - ElevenLabs Compatible TTS
"""

from .tts import (
    TalkLabsClient,
    VoiceSettings,
    generate,
    stream
)

__version__ = "1.0.1"
__all__ = [
    "TalkLabsClient",
    "VoiceSettings", 
    "generate",
    "stream"
]
